from distutils.core import setup

setup(
    name='131228_pytest_1',
    version='1.0.0',
    packages=[''],
    url='none',
    license='none',
    author='smith9',
    author_email='smith9@ms22.hinet.net',
    description='A easy printer of nested list'
)
